public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r13-269] libiberty: fix wrong replacent in comments
@ 2022-05-10 15:36 Martin Liska
  0 siblings, 0 replies; only message in thread
From: Martin Liska @ 2022-05-10 15:36 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:098f02aa154b308111cc1f520a577f5bb5f08377

commit r13-269-g098f02aa154b308111cc1f520a577f5bb5f08377
Author: Martin Liska <mliska@suse.cz>
Date:   Tue May 10 17:36:28 2022 +0200

    libiberty: fix wrong replacent in comments
    
    libiberty/ChangeLog:
    
            * regex.c: Restore comments.

Diff:
---
 libiberty/regex.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/libiberty/regex.c b/libiberty/regex.c
index c1738c989ab..84af5276ae8 100644
--- a/libiberty/regex.c
+++ b/libiberty/regex.c
@@ -384,8 +384,8 @@ typedef unsigned long int uintptr_t;
 # endif /* not using relocating allocator */
 
 
-/* True if `size1' is non-NULL and void *is pointing anywhere inside
-   `string1' or just past its end.  This works if void *is NULL, which is
+/* True if `size1' is non-NULL and PTR is pointing anywhere inside
+   `string1' or just past its end.  This works if PTR is NULL, which is
    a good thing.  */
 # define FIRST_STRING_P(ptr) 					\
   (size1 && string1 <= (ptr) && (ptr) <= string1 + size1)
@@ -5256,7 +5256,7 @@ PREFIX(re_search_2) (struct re_pattern_buffer *bufp, const char *string1,
 }
 
 #ifdef WCHAR
 /* This converts void *, a pointer into one of the search wchar_t strings
    `string1' and `string2' into an multibyte string offset from the
    beginning of that string. We use mbs_offset to optimize.
    See convert_mbs_to_wcs.  */
@@ -5266,7 +5266,7 @@ PREFIX(re_search_2) (struct re_pattern_buffer *bufp, const char *string1,
    : ((regoff_t)((mbs_offset2 != NULL? mbs_offset2[(ptr)-string2] : 0)	\
 		 + csize1)))
 #else /* BYTE */
 /* This converts void *, a pointer into one of the search strings `string1'
    and `string2' into an offset from the beginning of that string.  */
 # define POINTER_TO_OFFSET(ptr)			\
   (FIRST_STRING_P (ptr)				\


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-05-10 15:36 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -5256,7 +5256,7 @@ PREFIX(re_search_2) (struct re_pattern_buffer *bufp, const char *string1,
 
 #ifdef WCHAR
-/* This converts void *, a pointer into one of the search wchar_t strings
+/* This converts PTR, a pointer into one of the search wchar_t strings
    `string1' and `string2' into an multibyte string offset from the
    beginning of that string. We use mbs_offset to optimize.
@@ -5266,7 +5266,7 @@ PREFIX(re_search_2) (struct re_pattern_buffer *bufp, const char *string1,
 		 + csize1)))
 #else /* BYTE */
-/* This converts void *, a pointer into one of the search strings `string1'
+/* This converts PTR, a pointer into one of the search strings `string1'
    and `string2' into an offset from the beginning of that string.  */
 # define POINTER_TO_OFFSET(ptr)			\
2022-05-10 15:36 [gcc r13-269] libiberty: fix wrong replacent in comments Martin Liska

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).